@@ -1,6 +1,6 @@
 ###
-### $Rev: 42 $
-### $Release: 0.5.1 $
+### $Rev: 51 $
+### $Release: 0.6.0 $
 ### copyright(c) 2005 kuwata-lab all rights reserved.
 ###
 
@@ -36,7 +36,7 @@ module Kwalify
       attr_reader :length
       attr_reader :ident
       attr_reader :unique
-
+      attr_reader :classname
 
       def init(hash, path="", rule_table={})
          unless hash.is_a?(Hash)
@@ -67,6 +67,7 @@ module Kwalify
             when :unique    ;  _init_unique_value(  val, rule, path)
             when :sequence  ;  _init_sequence_value(val, rule, path, rule_table)
             when :mapping   ;  _init_mapping_value( val, rule, path, rule_table)
+            when :classname ;  _init_classname_value(val, rule, path)
             else
                #* key=:key_unknown  msg="unknown key."
                raise schema_error(:key_unknown, rule, curr_path, "#{key}:")
@@ -101,6 +102,15 @@ module Kwalify
       end
 
 
+      def _init_classname_value(val, rule, path)
+         @classname = val
+         unless @type == 'map'
+            #* key=:classname_notmap  msg="available only with map type."
+            raise schema_error(:classname_notmap, rule, "#{path}/classname", 'classname:')
+         end
+      end
+
+
       def _init_name_value(val, rule, path)
          @name = val
       end
