@@ -1,6 +1,6 @@
 ###
-### $Rev: 44 $
-### $Release: 0.5.1 $
+### $Rev: 51 $
+### $Release: 0.6.0 $
 ### copyright(c) 2005 kuwata-lab all rights reserved.
 ###
 
@@ -193,7 +193,7 @@ module Kwalify
          case value
          when /^-( |$)/
             data = parse_sequence(value_start_column, value)
-         when /^(:?[-.\w]+|'.*?'|".*?"|=|<<) *:( |$)/
+         when /^(:?:?[-.\w]+\*?|'.*?'|".*?"|=|<<) *:( |$)/
          #when /^:?["']?[-.\w]+["']? *:( |$)/			#'
             data = parse_mapping(value_start_column, value)
          when /^\[/, /^\{/
@@ -471,12 +471,13 @@ module Kwalify
 
       def parse_block_text(column, value)
          assert value =~ /^[>|\|]/
-         value =~ /^([>|\|])([-+]?)\s*(.*)$/
+         value =~ /^([>|\|])([-+]?)(\d+)?\s*(.*)$/
          char = $1
          indicator = $2
          sep = char == "|" ? "\n" : " "
-         #text = $3.empty? ? '' :  $3 + sep
-         text = $3
+         margin = $3 && !$3.empty? ? $3.to_i : nil
+         #text = $4.empty? ? '' :  $4 + sep
+         text = $4
          s = ''
          empty = ''
          min_indent = -1
@@ -493,8 +494,9 @@ module Kwalify
                empty = ''
             end
          end
-         s << empty if indicator == '+'
+         s << empty if indicator == '+' && char != '>'
          s[-1] = "" if indicator == '-'
+         min_indent = column + margin - 1 if margin
          if min_indent > 0
             sp = ' ' * min_indent
             s.gsub!(/^#{sp}/, '')
@@ -502,6 +504,7 @@ module Kwalify
          if char == '>'
             s.gsub!(/([^\n])\n([^\n])/, '\1 \2')
             s.gsub!(/\n(\n+)/, '\1')
+            s << empty if indicator == '+'
          end
          getline() if current_line() =~ /^\s*\#/
          return create_scalar(text + s)
@@ -547,11 +550,11 @@ module Kwalify
 
       def parse_mapping(column, value)
          #assert value =~ /^(:?["']?[-.\w]+["']? *):(( +)(.*))?$/         #'
-         assert value =~ /^((?::?[-.\w]+|'.*?'|".*?"|=|<<) *):(( +)(.*))?$/
+         assert value =~ /^((?::?[-.\w]+\*?|'.*?'|".*?"|=|<<) *):(( +)(.*))?$/
          map = create_mapping()  # {}
          while true
             #unless value =~ /^(:?["']?[-.\w]+["']? *):(( +)(.*))?$/      #'
-            unless value =~ /^((?::?[-.\w]+|'.*?'|".*?"|=|<<) *):(( +)(.*))?$/
+            unless value =~ /^((?::?[-.\w]+\*?|'.*?'|".*?"|=|<<) *):(( +)(.*))?$/
                #* key=:mapping_noitem  msg="mapping item is expected."
                raise syntax_error(:mapping_noitem)
             end
